==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/pl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link publiczny",
    "Photos" : "Zdjęcia",
    "On This Day" : "W tym dniu",
    "Your memories under your control" : "Twoje wspomnienia pod kontrolą",
    "All media" : "Wszystkie media",
    "Videos" : "Filmy",
    "Albums" : "Albumy",
    "Collaborative albums" : "Albumy wspólne",
    "People" : "Osoby",
    "Folders" : "Katalogi",
    "Favorites" : "Ulubione",
    "On this day" : "W tym dniu",
    "Shared with you" : "Udostępnione Tobie",
    "Tags" : "Etykiety",
    "Places" : "Miejsca",
    "Map" : "Mapa",
    "Photos settings" : "Ustawienia Zdjęć",
    "Mark selection as favorite" : "Oznacz wybrane jako ulubione",
    "Add selection to favorites" : "Dodaj wybrane do ulubionych",
    "Remove selection from favorites" : "Usuń wybrane z ulubionych",
    "Name of the album" : "Nazwa albumu",
    "Location of the album" : "Lokalizacja albumu",
    "Back" : "Poprzednia",
    "Add collaborators" : "Dodaj współpracowników",
    "Save" : "Zapisz",
    "Create album" : "Utwórz album",
    "Add to Album" : "Dodaj do albumu",
    "Add selection to album {albumName}" : "Dodaj wybór do albumu {albumName}",
    "Shared by" : "Udostępnione przez",
    "Create a new album." : "Utwórz nowy album.",
    "Create new album" : "Utwórz nowy album",
    "New album" : "Nowy album",
    "_%n item_::_%n photos and videos_" : ["%n pozycja","%n pozycje","%n pozycji","%n zdjęć i filmów"],
    "Failed to fetch collaborators list." : "Nie udało się pobrać listy współpracowników.",
    "Failed to update album." : "Nie udało się zaktualizować albumu.",
    "Add people or groups who can edit your album" : "Dodaj osoby lub grupy, które mogą edytować Twój album",
    "Search people or groups" : "Wyszukaj osoby lub grupy",
    "No recommendations. Start typing." : "Brak rekomendacji. Możesz napisać.",
    "Group" : "Grupa",
    "Remove {collaboratorLabel} from the collaborators list" : "Usuń {collaboratorLabel} z listy współpracowników",
    "Copy the public link" : "Kopiuj link publiczny",
    "Public link copied!" : "Skopiowano link publiczny!",
    "Copy public link" : "Kopiuj link publiczny",
    "Delete the public link" : "Usuń link publiczny",
    "Create public link share" : "Utwórz udostępnienie linku publicznego",
    "Share via public link" : "Udostępnij przez link publiczny",
    "This collection does not exist" : "Ta kolekcja nie istnieje",
    "An error occurred" : "Wystąpił błąd",
    "No picture for this day" : "Brak zdjęć z tego dnia",
    "Picture taken on this day will show up here." : "Tutaj pojawi się zdjęcie zrobione tego dnia.",
    "More photos from this day" : "Więcej zdjęć z tego dnia",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nieprzypisane zdjęcie","%n nieprzypisane zdjęcia","%n nieprzypisanych zdjęć","%n nieprzypisanych zdjęć"],
    "Favorite" : "Ulubiony",
    "Favorite image, open the full size \"{name}\" image" : "Ulubiony obraz, otwórz pełnowymiarowy obraz „{name}”.",
    "Open the full size \"{name}\" image" : "Otwórz obraz \"{name}\" w pełnym rozmiarze",
    "Select image {imageName}" : "Wybierz obraz {imageName}",
    "Open the \"{name}\" folder" : "Otwórz katalog „{name}”.",
    "Back to {folder}" : "Powrót do {folder}",
    "Go back" : "Wstecz",
    "Share this folder" : "Udostępnij ten katalog",
    "Dates" : "Daty",
    "Jump to specific date in list" : "Przejdź do określonej daty na liście",
    "Jump to {date}" : "Przejdź do {date}",
    "Add to {destination}" : "Dodaj do {destination}",
    "The destination folder is owned by {owner}" : "Katalog docelowy jest własnością {owner}",
    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
    "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
    "Delete source directory" : "Usuń katalog źródłowy",
    "Pick folder" : "Wybierz katalog",
    "Select a source folder for your media" : "Wybierz katalog źródłowy dla multimediów",
    "All folders" : "Wszystkie katalogi",
    "Add a Photos source for the timelines" : "Dodaj źródło zdjęć do osi czasu",
    "Add folder" : "Dodaj katalog",
    "Select the default upload location for your media" : "Wybierz domyślną lokalizację przesyłania multimediów",
    "Home" : "Strona główna",
    "Choose default Photos upload and Albums location" : "Wybierz domyślną lokalizację wysyłania zdjęć i albumów",
    "Choose a different folder" : "Wybierz inny katalog",
    "View" : "Podgląd",
    "Media folders" : "Katalogi multimediów",
    "Choose the folders from where photos and videos are shown." : "Wybierz katalogi, z których będą wyświetlane zdjęcia i filmy.",
    "Upload folder" : "Prześlij katalog",
    "Choose the folder where photos and albums are uploaded to." : "Wybierz katalog, do którego przesyłane są zdjęcia i albumy.",
    "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Unselect all" : "Odznacz wszystko",
    "Add photos to this album" : "Dodaj zdjęcia do tego albumu",
    "Manage collaborators for this album" : "Zarządzaj współpracownikami tego albumu",
    "Open actions menu" : "Otwórz menu działań",
    "Edit album details" : "Edytuj szczegóły albumu",
    "Download all files in album" : "Pobierz wszystkie pliki z albumu",
    "Delete album" : "Usuń album",
    "Download selected files" : "Pobierz wybrane pliki",
    "Remove selection from album" : "Usuń wybrane z albumu",
    "This album does not have any photos or videos yet!" : "W tym albumie nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to {albumName}" : "Dodaj zdjęcia do albumu {albumName}",
    "Manage collaborators" : "Zarządzaj współpracownikami",
    "Save collaborators for this album." : "Zapisywanie współpracowników dla tego albumu.",
    "Cover photo for album {albumName}" : "Zdjęcie na okładkę albumu {albumName}",
    "There is no album yet!" : "Nie ma jeszcze albumu!",
    "This person could not be found" : "Nie można znaleźć osoby",
    "Rename person" : "Zmień nazwę osoby",
    "Merge with different person" : "Połącz z inną osobą",
    "Download selected photos" : "Pobierz wybrane zdjęcia",
    "Remove from favorites" : "Usuń z ulubionych",
    "Remove person" : "Usuń osobę",
    "Name of this person" : "Nazwa tej osoby",
    "Save." : "Zapisz.",
    "Merge person" : "Połącz osobę",
    "Move to different person" : "Przenieś do innej osoby",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Przenieś zdjęcie do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby"],
    "_Remove photo from person_::_Remove photos from person_" : ["Usuń zdjęcie od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby"],
    "This might take some time depending on the size of your photo library." : "Może to zająć trochę czasu, w zależności od rozmiaru biblioteki zdjęć.",
    "Recognized people will show up here" : "Rozpoznane osoby pojawią się tutaj",
    "This folder does not exist" : "Ten katalog nie istnieje",
    "Loading folders …" : "Wczytywanie katalogów …",
    "No photos in here" : "Brak zdjęć",
    "Taken on {date} at {time}" : "Zrobiono {date} o {time}",
    "This place does not have any photos or videos yet!" : "To miejsce nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to this place" : "Dodaj zdjęcia do tego miejsca",
    "Cover photo for place {placeName}" : "Zdjęcie na okładkę {placeName}",
    "There is no place yet!" : "Nie ma jeszcze miejsca!",
    "Cover photo for shared album {albumName}." : "Zdjęcie na okładkę albumu udostępnionego {albumName}.",
    "Back to tags overview" : "Powrót do przeglądania etykiet",
    "No photos with this tag yet" : "Nie ma jeszcze zdjęć z tą etykietą",
    "No tags yet" : "Brak etykiet",
    "Photos with tags will show up here" : "Zdjęcia z etykietami pojawią się tutaj",
    "Popular tags" : "Popularne etykiety",
    "All tags" : "Wszystkie etykiety",
    "One of the source folders does not exist" : "Jeden z katalogów źródłowych nie istnieje",
    "Add to album" : "Dodaj do albumu",
    "Delete selection" : "Usuń wybrane",
    "No photos or videos in here" : "Nie ma tu zdjęć ani filmów",
    "Unassigned faces" : "Nieprzypisane twarze",
    "_%n photos_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Failed to fetch collection." : "Nie udało się pobrać kolekcji.",
    "Failed to fetch collections list." : "Nie udało się pobrać listę kolekcji.",
    "Failed to fetch faces list." : "Nie udało się pobrać listy twarzy.",
    "All your media" : "Wszystkie Twoje media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albumy udostępnione",
    "Shared album {title}" : "Udostępniony album {title}",
    "Public album {title}" : "Publiczny album {title}",
    "Tagged photos" : "Oznaczone zdjęcia",
    "Tagged photo {title}" : "Zdjęcie oznaczone etykietą {title}",
    "{title}'s face" : "Twarz {title}",
    "{startDate} to {endDate}" : "{startDate} do {endDate}",
    "Details" : "Szczegóły",
    "Failed to rename {oldName} to {faceName}." : "Nie udało się zmienić nazwy {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nie udało się usunąć {faceName}.",
    "Failed to delete {fileId}." : "Nie udało się usunąć {fileId}.",
    "Failed to delete {fileName}." : "Nie udało się usunąć {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nie udało się ustawić statusu ulubionego dla {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nie udało się ustawić statusu ulubionego dla {fileName}.",
    "Could not load photos folder" : "Nie można wczytać katalogu ze zdjęciami",
    "One of the source folders does not exists" : "Jeden z katalogów źródłowych nie istnieje",
    "Add" : "Dodaj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/pl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link publiczny",
    "Photos" : "Zdjęcia",
    "On This Day" : "W tym dniu",
    "Your memories under your control" : "Twoje wspomnienia pod kontrolą",
    "All media" : "Wszystkie media",
    "Videos" : "Filmy",
    "Albums" : "Albumy",
    "Collaborative albums" : "Albumy wspólne",
    "People" : "Osoby",
    "Folders" : "Katalogi",
    "Favorites" : "Ulubione",
    "On this day" : "W tym dniu",
    "Shared with you" : "Udostępnione Tobie",
    "Tags" : "Etykiety",
    "Places" : "Miejsca",
    "Map" : "Mapa",
    "Photos settings" : "Ustawienia Zdjęć",
    "Mark selection as favorite" : "Oznacz wybrane jako ulubione",
    "Add selection to favorites" : "Dodaj wybrane do ulubionych",
    "Remove selection from favorites" : "Usuń wybrane z ulubionych",
    "Name of the album" : "Nazwa albumu",
    "Location of the album" : "Lokalizacja albumu",
    "Back" : "Poprzednia",
    "Add collaborators" : "Dodaj współpracowników",
    "Save" : "Zapisz",
    "Create album" : "Utwórz album",
    "Add to Album" : "Dodaj do albumu",
    "Add selection to album {albumName}" : "Dodaj wybór do albumu {albumName}",
    "Shared by" : "Udostępnione przez",
    "Create a new album." : "Utwórz nowy album.",
    "Create new album" : "Utwórz nowy album",
    "New album" : "Nowy album",
    "_%n item_::_%n photos and videos_" : ["%n pozycja","%n pozycje","%n pozycji","%n zdjęć i filmów"],
    "Failed to fetch collaborators list." : "Nie udało się pobrać listy współpracowników.",
    "Failed to update album." : "Nie udało się zaktualizować albumu.",
    "Add people or groups who can edit your album" : "Dodaj osoby lub grupy, które mogą edytować Twój album",
    "Search people or groups" : "Wyszukaj osoby lub grupy",
    "No recommendations. Start typing." : "Brak rekomendacji. Możesz napisać.",
    "Copy the public link" : "Kopiuj link publiczny",
    "Public link copied!" : "Skopiowano link publiczny!",
    "Copy public link" : "Kopiuj link publiczny",
    "Delete the public link" : "Usuń link publiczny",
    "Create public link share" : "Utwórz udostępnienie linku publicznego",
    "Share via public link" : "Udostępnij przez link publiczny",
    "This collection does not exist" : "Ta kolekcja nie istnieje",
    "An error occurred" : "Wystąpił błąd",
    "No picture for this day" : "Brak zdjęć z tego dnia",
    "Picture taken on this day will show up here." : "Tutaj pojawi się zdjęcie zrobione tego dnia.",
    "More photos from this day" : "Więcej zdjęć z tego dnia",
    "_%n photos_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nieprzypisane zdjęcie","%n nieprzypisane zdjęcia","%n nieprzypisanych zdjęć","%n nieprzypisanych zdjęć"],
    "Favorite" : "Ulubiony",
    "Favorite image, open the full size \"{name}\" image" : "Ulubiony obraz, otwórz pełnowymiarowy obraz „{name}”.",
    "Open the full size \"{name}\" image" : "Otwórz obraz \"{name}\" w pełnym rozmiarze",
    "Select image {imageName}" : "Wybierz obraz {imageName}",
    "Open the \"{name}\" folder" : "Otwórz katalog „{name}”.",
    "Go back" : "Wstecz",
    "Select a custom date range" : "Wybierz niestandardowy zakres dat",
    "Select a date range" : "Wybierz zakres dat",
    "Date range" : "Zakres dat",
    "Select filters" : "Wybierz filtry",
    "Dates" : "Daty",
    "Jump to specific date in list" : "Przejdź do określonej daty na liście",
    "Jump to {date}" : "Przejdź do {date}",
    "Add to {destination}" : "Dodaj do {destination}",
    "The destination folder is owned by {owner}" : "Katalog docelowy jest własnością {owner}",
    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
    "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
    "Delete source directory" : "Usuń katalog źródłowy",
    "Pick folder" : "Wybierz katalog",
    "Select a source folder for your media" : "Wybierz katalog źródłowy dla multimediów",
    "All folders" : "Wszystkie katalogi",
    "Add a Photos source for the timelines" : "Dodaj źródło zdjęć do osi czasu",
    "Add folder" : "Dodaj katalog",
    "Select the default upload location for your media" : "Wybierz domyślną lokalizację przesyłania multimediów",
    "Home" : "Strona główna",
    "Choose default Photos upload and Albums location" : "Wybierz domyślną lokalizację wysyłania zdjęć i albumów",
    "Choose a different folder" : "Wybierz inny katalog",
    "View" : "Podgląd",
    "Media folders" : "Katalogi multimediów",
    "Choose the folders from where photos and videos are shown." : "Wybierz katalogi, z których będą wyświetlane zdjęcia i filmy.",
    "Upload folder" : "Prześlij katalog",
    "Choose the folder where photos and albums are uploaded to." : "Wybierz katalog, do którego przesyłane są zdjęcia i albumy.",
    "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
    "Unselect all" : "Odznacz wszystko",
    "Add photos to this album" : "Dodaj zdjęcia do tego albumu",
    "Manage collaborators for this album" : "Zarządzaj współpracownikami tego albumu",
    "Open actions menu" : "Otwórz menu działań",
    "Edit album details" : "Edytuj szczegóły albumu",
    "Download all files in album" : "Pobierz wszystkie pliki z albumu",
    "Delete album" : "Usuń album",
    "Download selected files" : "Pobierz wybrane pliki",
    "Remove selection from album" : "Usuń wybrane z albumu",
    "This album does not have any photos or videos yet!" : "W tym albumie nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to {albumName}" : "Dodaj zdjęcia do albumu {albumName}",
    "Manage collaborators" : "Zarządzaj współpracownikami",
    "Save collaborators for this album." : "Zapisywanie współpracowników dla tego albumu.",
    "Cover photo for album {albumName}" : "Zdjęcie na okładkę albumu {albumName}",
    "There is no album yet!" : "Nie ma jeszcze albumu!",
    "This person could not be found" : "Nie można znaleźć osoby",
    "Rename person" : "Zmień nazwę osoby",
    "Merge with different person" : "Połącz z inną osobą",
    "Download selected photos" : "Pobierz wybrane zdjęcia",
    "Remove from favorites" : "Usuń z ulubionych",
    "Remove person" : "Usuń osobę",
    "Name of this person" : "Nazwa tej osoby",
    "Save." : "Zapisz.",
    "Merge person" : "Połącz osobę",
    "Move to different person" : "Przenieś do innej osoby",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Przenieś zdjęcie do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby","Przenieś zdjęcia do innej osoby"],
    "_Remove photo from person_::_Remove photos from person_" : ["Usuń zdjęcie od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby","Usuń zdjęcia od osoby"],
    "This might take some time depending on the size of your photo library." : "Może to zająć trochę czasu, w zależności od rozmiaru biblioteki zdjęć.",
    "Recognized people will show up here" : "Rozpoznane osoby pojawią się tutaj",
    "This folder does not exist" : "Ten katalog nie istnieje",
    "Loading folders…" : "Pobieram katalogi…",
    "No photos in here" : "Brak zdjęć",
    "Taken on {date} at {time}" : "Zrobiono {date} o {time}",
    "This place does not have any photos or videos yet!" : "To miejsce nie ma jeszcze żadnych zdjęć ani filmów!",
    "Add photos to this place" : "Dodaj zdjęcia do tego miejsca",
    "Cover photo for place {placeName}" : "Zdjęcie na okładkę {placeName}",
    "There is no place yet!" : "Nie ma jeszcze miejsca!",
    "Cover photo for shared album {albumName}" : "Zdjęcie okładkowe dla udostępnionego albumu {albumName}",
    "Back to tags overview" : "Powrót do przeglądania etykiet",
    "No photos with this tag yet" : "Nie ma jeszcze zdjęć z tą etykietą",
    "No tags yet" : "Brak etykiet",
    "Photos with tags will show up here" : "Zdjęcia z etykietami pojawią się tutaj",
    "Popular tags" : "Popularne etykiety",
    "All tags" : "Wszystkie etykiety",
    "Create new album from filters" : "Utwórz nowy album z filtrów",
    "One of the source folders does not exist" : "Jeden z katalogów źródłowych nie istnieje",
    "Add to album" : "Dodaj do albumu",
    "Delete selection" : "Usuń wybrane",
    "No photos or videos in here" : "Nie ma tu zdjęć ani filmów",
    "Unassigned faces" : "Nieprzypisane twarze",
    "Failed to fetch collection." : "Nie udało się pobrać kolekcji.",
    "Failed to fetch collections list." : "Nie udało się pobrać listę kolekcji.",
    "Failed to fetch faces list." : "Nie udało się pobrać listy twarzy.",
    "Error fetching files" : "Błąd podczas pobierania plików",
    "All your media" : "Wszystkie Twoje media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albumy udostępnione",
    "Shared album {title}" : "Udostępniony album {title}",
    "Public album {title}" : "Publiczny album {title}",
    "Tagged photos" : "Oznaczone zdjęcia",
    "Tagged photo {title}" : "Zdjęcie oznaczone etykietą {title}",
    "{title}'s face" : "Twarz {title}",
    "Last week" : "W zeszłym tygodniu",
    "Last Month" : "Ostatni miesiąc",
    "Custom…" : "Niestandardowy…",
    "{startDate} to {endDate}" : "{startDate} do {endDate}",
    "Details" : "Szczegóły",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Nie udało się dodać {fileBaseName} do kolekcji {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Nie udało się usunąć {fileBaseName}",
    "Failed to create {collectionFileName}" : "Nie udało się utworzyć {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Nie udało się zmienić nazwy {currentCollectionFileName} na {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Nie udało się zaktualizować właściwości {collectionFileName} o {properties}",
    "Failed to delete {collectionFileName}" : "Nie udało się usunąć {collectionFileName}",
    "Failed to move {fileBaseName} to person {faceName}" : "Nie udało się przenieść {fileBaseName} do osoby {faceName}",
    "Failed to remove {fileBaseName}" : "Nie udało się usunąć {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Nie udało się zmienić nazwy {oldName} na {faceName}",
    "Failed to delete {faceName}" : "Nie udało się usunąć {faceName}",
    "Failed to delete {fileId}" : "Nie udało się usunąć {fileId}",
    "Failed to delete {fileName}" : "Nie udało się usunąć {fileName}",
    "Failed to set favorite state for {fileId}" : "Nie udało się ustawić stanu ulubionego dla {fileId}",
    "Failed to set favorite state for {fileName}" : "Nie udało się ustawić stanu ulubionego dla {fileName}",
    "Could not load photos folder" : "Nie można wczytać katalogu ze zdjęciami",
    "Group" : "Grupa",
    "Remove {collaboratorLabel} from the collaborators list" : "Usuń {collaboratorLabel} z listy współpracowników",
    "Back to {folder}" : "Powrót do {folder}",
    "Share this folder" : "Udostępnij ten katalog",
    "Loading folders …" : "Wczytywanie katalogów …",
    "One of the source folders does not exists" : "Jeden z katalogów źródłowych nie istnieje",
    "Add" : "Dodaj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
